@@ -57,6 +57,11 @@ class TestProfileWithoutCaching(unittest.TestCase):
     def tearDown(self):
         setRequest(None)
 
+    def assertBrowserEmpty(self, browser):
+        # assert that browser.contents is an empty bytes/string/unicode.
+        self.assertIsInstance(browser.contents, (six.binary_type, six.text_type))
+        self.assertFalse(browser.contents)
+
     def test_composite_views(self):
 
         catalog = self.portal['portal_catalog']
@@ -188,7 +193,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
         browser.open(self.portal['f1']['d1'].absolute_url())
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual(b'', browser.contents)
+        self.assertBrowserEmpty(browser)
 
         # Request the anonymous folder
         now = stable_now()
@@ -255,7 +260,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual(b'', browser.contents)
+        self.assertBrowserEmpty(browser)
 
         # Edit the page to update the etag
         testText2 = 'Testing... body two'
@@ -341,7 +346,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual(b'', browser.contents)
+        self.assertBrowserEmpty(browser)
 
         # Request the authenticated rss feed
         now = stable_now()
@@ -427,7 +432,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual(b'', browser.contents)
+        self.assertBrowserEmpty(browser)
 
         # Request an image scale
         now = stable_now()
@@ -476,7 +481,7 @@ class TestProfileWithoutCaching(unittest.TestCase):
                          browser.headers['X-Cache-Operation'])
         # This should be a 304 response
         self.assertEqual('304 Not Modified', browser.headers['Status'])
-        self.assertEqual(b'', browser.contents)
+        self.assertBrowserEmpty(browser)
 
         # Request a large datafile (over 64K) to test files that use
         # the "response.write()" function to initiate a streamed response.
