@@ -9,8 +9,7 @@ from plone.app.caching.purge import purgeOnModified
 from plone.app.caching.purge import purgeOnMovedOrRemoved
 from plone.app.caching.purge import ScalesPurgePaths
 from plone.app.caching.testing import PLONE_APP_CACHING_FUNCTIONAL_TESTING
-from plone.app.contenttypes.behaviors.leadimage \
-    import ILeadImageBehavior
+from plone.app.contenttypes.behaviors.leadimage import ILeadImageBehavior
 from plone.app.contenttypes.interfaces import IDocument
 from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
@@ -56,13 +55,13 @@ if HAVE_AT:
 def getData(filename):
     from os.path import dirname, join
     from plone.app.caching import tests
+
     filename = join(dirname(tests.__file__), filename)
-    data = open(filename, 'rb').read()
-    return data
+    with open(filename, "rb") as myfile:
+        return myfile.read()
 
 
 class Handler(object):
-
     def __init__(self):
         self.invocations = []
 
@@ -72,14 +71,13 @@ class Handler(object):
 
 
 class FauxRequest(dict):
-    REQUEST_METHOD = 'POST'
-    URL = 'http://nohost/test'
-    form = ('form.submitted',)
+    REQUEST_METHOD = "POST"
+    URL = "http://nohost/test"
+    form = ("form.submitted",)
 
 
 @implementer(IContentish)
 class FauxNonContent(Explicit):
-
     def __init__(self, name=None):
         self.__name__ = name
         self.__parent__ = None  # may be overridden by acquisition
@@ -90,24 +88,24 @@ class FauxNonContent(Explicit):
     def virtual_url_path(self):
         parent = aq_base(self.__parent__)
         if parent is not None:
-            return parent.virtual_url_path() + '/' + self.__name__
+            return parent.virtual_url_path() + "/" + self.__name__
         else:
             return self.__name__
 
     def getPhysicalPath(self):
-        return ('', )
+        return ("",)
 
     def getParentNode(self):
-        return FauxNonContent('folder')
+        return FauxNonContent("folder")
 
 
 @implementer(IBrowserDefault)
 class FauxContent(FauxNonContent):
 
-    portal_type = 'testtype'
+    portal_type = "testtype"
 
     def defaultView(self):
-        return 'default-view'
+        return "default-view"
 
 
 @implementer(IDiscussionResponse)
@@ -122,21 +120,18 @@ class TestPurgeRedispatch(unittest.TestCase):
     def setUp(self):
         self.handler = Handler()
         provideHandler(self.handler.handler)
-
         provideHandler(objectEventNotify)
         provideHandler(purgeOnModified)
         provideHandler(purgeOnMovedOrRemoved)
-
         provideAdapter(persistentFieldAdapter)
         provideUtility(Registry(), IRegistry)
         registry = getUtility(IRegistry)
         registry.registerInterface(IPloneCacheSettings)
-
         ploneSettings = registry.forInterface(IPloneCacheSettings)
-        ploneSettings.purgedContentTypes = ('testtype',)
+        ploneSettings.purgedContentTypes = ("testtype",)
 
     def test_not_purged(self):
-        context = FauxNonContent('new').__of__(FauxContent())
+        context = FauxNonContent("new").__of__(FauxContent())
 
         notify(ObjectModifiedEvent(context))
         notify(ObjectAddedEvent(context))
@@ -153,37 +148,43 @@ class TestPurgeRedispatch(unittest.TestCase):
         self.assertEqual(context, self.handler.invocations[0].object)
 
     def test_added(self):
-        context = FauxContent('new').__of__(FauxContent())
+        context = FauxContent("new").__of__(FauxContent())
 
-        notify(ObjectAddedEvent(context, context.__parent__, 'new'))
+        notify(ObjectAddedEvent(context, context.__parent__, "new"))
 
         self.assertEqual(0, len(self.handler.invocations))
 
     def test_moved(self):
-        context = FauxContent('new').__of__(FauxContent())
+        context = FauxContent("new").__of__(FauxContent())
+        request = FauxRequest()
+        setRequest(request)
 
-        notify(ObjectMovedEvent(context, FauxContent(), 'old',
-                                context.__parent__, 'new'))
+        notify(
+            ObjectMovedEvent(context, FauxContent(), "old", context.__parent__, "new")
+        )
 
         self.assertEqual(2, len(self.handler.invocations))
         self.assertEqual(context, self.handler.invocations[0].object)
 
     def test_renamed(self):
-        context = FauxContent('new').__of__(FauxContent())
+        context = FauxContent("new").__of__(FauxContent())
 
-        notify(ObjectMovedEvent(context,
-                                context.__parent__, 'old',
-                                context.__parent__, 'new'))
+        notify(
+            ObjectMovedEvent(
+                context, context.__parent__, "old", context.__parent__, "new"
+            )
+        )
 
         self.assertEqual(2, len(self.handler.invocations))
         self.assertEqual(context, self.handler.invocations[0].object)
 
     def test_removed(self):
-        context = FauxContent('new').__of__(FauxContent())
-        request = getRequest()
-        request.URL = 'http://nohost/delete_confirmation'
+        context = FauxContent("new").__of__(FauxContent())
+        request = FauxRequest()
+        request.URL = "http://nohost/delete_confirmation"
+        setRequest(request)
 
-        notify(ObjectRemovedEvent(context, context.__parent__, 'new'))
+        notify(ObjectRemovedEvent(context, context.__parent__, "new"))
 
         self.assertEqual(2, len(self.handler.invocations))
         self.assertEqual(context, self.handler.invocations[0].object)
@@ -194,42 +195,42 @@ class TestContentPurgePaths(unittest.TestCase):
     layer = UNIT_TESTING
 
     def test_no_default_view(self):
-        context = FauxNonContent('foo')
+        context = FauxNonContent("foo")
         purger = ContentPurgePaths(context)
 
-        self.assertEqual(['/foo/', '/foo/view'],
-                         list(purger.getRelativePaths()))
+        self.assertEqual(["/foo/", "/foo/view"], list(purger.getRelativePaths()))
         self.assertEqual([], list(purger.getAbsolutePaths()))
 
     def test_default_view(self):
-        context = FauxContent('foo')
-        purger = ContentPurgePaths(context)
-
-        self.assertEqual(['/foo/', '/foo/view', '/foo/default-view'],
-                         list(purger.getRelativePaths()))
-        self.assertEqual([], list(purger.getAbsolutePaths()))
-
-    def test_parent_not_default_view(self):
-        context = FauxContent('foo').__of__(FauxContent('bar'))
+        context = FauxContent("foo")
         purger = ContentPurgePaths(context)
 
         self.assertEqual(
-            ['/bar/foo/', '/bar/foo/view', '/bar/foo/default-view'],
+            ["/foo/", "/foo/view", "/foo/default-view"], list(purger.getRelativePaths())
+        )
+        self.assertEqual([], list(purger.getAbsolutePaths()))
+
+    def test_parent_not_default_view(self):
+        context = FauxContent("foo").__of__(FauxContent("bar"))
+        purger = ContentPurgePaths(context)
+
+        self.assertEqual(
+            ["/bar/foo/", "/bar/foo/view", "/bar/foo/default-view"],
             list(purger.getRelativePaths()),
         )
         self.assertEqual([], list(purger.getAbsolutePaths()))
 
     def test_parent_default_view(self):
-        context = FauxContent('default-view').__of__(FauxContent('bar'))
+        context = FauxContent("default-view").__of__(FauxContent("bar"))
         purger = ContentPurgePaths(context)
         self.assertEqual(
             [
-                '/bar/default-view/',
-                '/bar/default-view/view',
-                '/bar/default-view/default-view',
-                '/bar',
-                '/bar/',
-                '/bar/view',
+                "/bar/default-view/",
+                "/bar/default-view/view",
+                "/bar/default-view/default-view",
+                "/bar",
+                "/bar/",
+                "/bar/view",
             ],
             list(purger.getRelativePaths()),
         )
@@ -241,25 +242,23 @@ class TestDiscussionItemPurgePaths(unittest.TestCase):
     layer = UNIT_TESTING
 
     def setUp(self):
-
         @implementer(IPurgePaths)
         @adapter(FauxContent)
         class FauxContentPurgePaths(object):
-
             def __init__(self, context):
                 self.context = context
 
             def getRelativePaths(self):
-                return ['/' + self.context.virtual_url_path()]
+                return ["/" + self.context.virtual_url_path()]
 
             def getAbsolutePaths(self):
-                return ['/purgeme']
+                return ["/purgeme"]
 
-        provideAdapter(FauxContentPurgePaths, name='testpurge')
+        provideAdapter(FauxContentPurgePaths, name="testpurge")
 
     def test_no_tool(self):
-        root = FauxContent('')
-        content = FauxContent('foo').__of__(root)
+        root = FauxContent("")
+        content = FauxContent("foo").__of__(root)
         discussable = FauxDiscussable().__of__(content)
 
         request = FauxRequest()
@@ -271,12 +270,11 @@ class TestDiscussionItemPurgePaths(unittest.TestCase):
         self.assertEqual([], list(purge.getAbsolutePaths()))
 
     def test_no_request(self):
-        root = FauxContent('app')
-        content = FauxContent('foo').__of__(root)
+        root = FauxContent("app")
+        content = FauxContent("foo").__of__(root)
         discussable = FauxDiscussable().__of__(content)
 
         class FauxPloneTool(object):
-
             def getDiscussionThread(self, item):
                 return [content, item]
 
@@ -290,12 +288,11 @@ class TestDiscussionItemPurgePaths(unittest.TestCase):
         self.assertEqual([], list(purge.getAbsolutePaths()))
 
     def test_no_discussion_thread(self):
-        root = FauxContent('app')
-        content = FauxContent('foo').__of__(root)
+        root = FauxContent("app")
+        content = FauxContent("foo").__of__(root)
         discussable = FauxDiscussable().__of__(content)
 
         class FauxPloneTool(object):
-
             def getDiscussionThread(self, item):
                 return []
 
@@ -310,12 +307,11 @@ class TestDiscussionItemPurgePaths(unittest.TestCase):
         self.assertEqual([], list(purge.getAbsolutePaths()))
 
     def test_paths_of_root(self):
-        root = FauxContent('app')
-        content = FauxContent('foo').__of__(root)
+        root = FauxContent("app")
+        content = FauxContent("foo").__of__(root)
         discussable = FauxDiscussable().__of__(content)
 
         class FauxPloneTool(object):
-
             def getDiscussionThread(self, item):
                 return [content, item]
 
@@ -326,11 +322,11 @@ class TestDiscussionItemPurgePaths(unittest.TestCase):
 
         purge = DiscussionItemPurgePaths(discussable)
 
-        self.assertEqual(['/app/foo'], list(purge.getRelativePaths()))
-        self.assertEqual(['/purgeme'], list(purge.getAbsolutePaths()))
+        self.assertEqual(["/app/foo"], list(purge.getRelativePaths()))
+        self.assertEqual(["/purgeme"], list(purge.getAbsolutePaths()))
 
 
-@unittest.skipUnless(HAVE_AT, 'Only run with AT')
+@unittest.skipUnless(HAVE_AT, "Only run with AT")
 class TestObjectFieldPurgePaths(unittest.TestCase):
 
     maxDiff = None
@@ -340,11 +336,10 @@ class TestObjectFieldPurgePaths(unittest.TestCase):
         provideAdapter(instanceSchemaFactory)
 
     def test_no_file_image_fields(self):
-
         class ATNoFields(atapi.BaseContent):
-            schema = atapi.Schema((atapi.StringField('foo'),))
+            schema = atapi.Schema((atapi.StringField("foo"),))
 
-        context = ATNoFields('foo')
+        context = ATNoFields("foo")
         purger = ObjectFieldPurgePaths(context)
 
         self.assertEqual([], list(purger.getRelativePaths()))
@@ -354,68 +349,73 @@ class TestObjectFieldPurgePaths(unittest.TestCase):
         from plone.app.blob.field import BlobField
 
         class ATMultipleFields(atapi.BaseContent):
-            schema = atapi.Schema((
-                atapi.StringField('foo'),
-                atapi.FileField('file1'),
-                atapi.ImageField('image1'),
-                atapi.ImageField('image2', sizes={
-                                 'mini': (50, 50), 'normal': (100, 100)}),
-                BlobField('blob1'),
-            ))
+            schema = atapi.Schema(
+                (
+                    atapi.StringField("foo"),
+                    atapi.FileField("file1"),
+                    atapi.ImageField("image1"),
+                    atapi.ImageField(
+                        "image2", sizes={"mini": (50, 50), "normal": (100, 100)}
+                    ),
+                    BlobField("blob1"),
+                )
+            )
 
-        root = FauxContent('')
-        context = ATMultipleFields('foo').__of__(root)
+        root = FauxContent("")
+        context = ATMultipleFields("foo").__of__(root)
         purger = ObjectFieldPurgePaths(context)
 
         self.assertEqual(
             [
-                '/foo/download',
-                '/foo/at_download',
-                '/foo/at_download/file1',
-                '/foo/file1',
-                '/foo/at_download/image1',
-                '/foo/image1',
-                '/foo/image1_thumb',
-                '/foo/at_download/image2',
-                '/foo/image2',
-                '/foo/image2_mini',
-                '/foo/image2_normal',
-                '/foo/at_download/blob1',
-                '/foo/blob1',
+                "/foo/download",
+                "/foo/at_download",
+                "/foo/at_download/file1",
+                "/foo/file1",
+                "/foo/at_download/image1",
+                "/foo/image1",
+                "/foo/image1_thumb",
+                "/foo/at_download/image2",
+                "/foo/image2",
+                "/foo/image2_mini",
+                "/foo/image2_normal",
+                "/foo/at_download/blob1",
+                "/foo/blob1",
             ],
             list(purger.getRelativePaths()),
         )
         self.assertEqual([], list(purger.getAbsolutePaths()))
 
     def test_file_image_text_fields(self):
-
         class ATMultipleFields(atapi.BaseContent):
-            schema = atapi.Schema((
-                atapi.StringField('foo'),
-                atapi.FileField('file1'),
-                atapi.ImageField('image1'),
-                atapi.ImageField('image2', sizes={
-                                 'mini': (50, 50), 'normal': (100, 100)}),
-                atapi.TextField('text'),
-            ))
+            schema = atapi.Schema(
+                (
+                    atapi.StringField("foo"),
+                    atapi.FileField("file1"),
+                    atapi.ImageField("image1"),
+                    atapi.ImageField(
+                        "image2", sizes={"mini": (50, 50), "normal": (100, 100)}
+                    ),
+                    atapi.TextField("text"),
+                )
+            )
 
-        root = FauxContent('')
-        context = ATMultipleFields('foo').__of__(root)
+        root = FauxContent("")
+        context = ATMultipleFields("foo").__of__(root)
         purger = ObjectFieldPurgePaths(context)
 
         self.assertEqual(
             [
-                '/foo/download',
-                '/foo/at_download',
-                '/foo/at_download/file1',
-                '/foo/file1',
-                '/foo/at_download/image1',
-                '/foo/image1',
-                '/foo/image1_thumb',
-                '/foo/at_download/image2',
-                '/foo/image2',
-                '/foo/image2_mini',
-                '/foo/image2_normal',
+                "/foo/download",
+                "/foo/at_download",
+                "/foo/at_download/file1",
+                "/foo/file1",
+                "/foo/at_download/image1",
+                "/foo/image1",
+                "/foo/image1_thumb",
+                "/foo/at_download/image2",
+                "/foo/image2",
+                "/foo/image2_mini",
+                "/foo/image2_normal",
             ],
             list(purger.getRelativePaths()),
         )
@@ -428,28 +428,20 @@ class TestScalesPurgePaths(unittest.TestCase):
 
     def setUp(self):
 
-        self.portal = self.layer['portal']
-        setRoles(self.portal, TEST_USER_ID, ['Manager'])
-        self.portal.invokeFactory('Folder', 'media')
+        self.portal = self.layer["portal"]
+        setRoles(self.portal, TEST_USER_ID, ["Manager"])
+        self.portal.invokeFactory("Folder", "media")
         self.folder = self.portal.media
-        self.folder.invokeFactory(
-            'Image',
-            'image',
-            title='Test Image')
-        self.image_type = self.folder['image']
+        self.folder.invokeFactory("Image", "image", title="Test Image")
+        self.image_type = self.folder["image"]
         self.image_type.image = NamedImage(
-            getData('data/plone-app-caching.jpg'),
-            'image/jpg',
-            u'plone-app-caching.jpg')
-        self.folder.invokeFactory(
-            'File',
-            'file',
-            title=u'Töst File')
-        self.file = self.folder['file']
+            getData("data/plone-app-caching.jpg"), "image/jpg", u"plone-app-caching.jpg"
+        )
+        self.folder.invokeFactory("File", "file", title=u"Töst File")
+        self.file = self.folder["file"]
         self.file.file = NamedFile(
-            getData('data/testfile.csv'),
-            'text/csv',
-            u'data/töstfile.csv')
+            getData("data/testfile.csv"), "text/csv", u"data/töstfile.csv"
+        )
 
         # Create a page with a lead image.
         # For the purposes of testing, we will use the Document type and
@@ -460,7 +452,7 @@ class TestScalesPurgePaths(unittest.TestCase):
         class TestingAssignable(object):
 
             enabled = [ILeadImageBehavior]
-            name = 'plone.leadimage'
+            name = "plone.leadimage"
 
             def __init__(self, context):
                 self.context = context
@@ -475,44 +467,40 @@ class TestScalesPurgePaths(unittest.TestCase):
 
         provideAdapter(TestingAssignable)
 
-        self.folder.invokeFactory(
-            'Document',
-            'page',
-            title='Test Page')
-        self.page = self.folder['page']
+        self.folder.invokeFactory("Document", "page", title="Test Page")
+        self.page = self.folder["page"]
 
         leadimage_adapter = ILeadImageBehavior(self.page)
         leadimage_adapter.image = NamedImage(
-            getData('data/plone-app-caching.jpg'),
-            'image/jpg',
-            u'plone-app-caching.jpg')
+            getData("data/plone-app-caching.jpg"), "image/jpg", u"plone-app-caching.jpg"
+        )
 
         setRoles(self.portal, TEST_USER_ID, TEST_USER_ROLES)
 
     def test_scale_purge_paths(self):
-        prefix = '/'.join(self.image_type.getPhysicalPath())
+        prefix = "/".join(self.image_type.getPhysicalPath())
         purge = ScalesPurgePaths(self.image_type)
         paths = purge.getRelativePaths()
         scales = purge.getScales()
-        scalepaths = [prefix + '/@@images/image/' + str(i) for i in scales]
+        scalepaths = [prefix + "/@@images/image/" + str(i) for i in scales]
         [self.assertIn(j, paths) for j in scalepaths]
         # lead image scales (example for an image field of a behavior)
-        prefix = '/'.join(self.page.getPhysicalPath())
+        prefix = "/".join(self.page.getPhysicalPath())
         purge = ScalesPurgePaths(self.page)
         paths = purge.getRelativePaths()
         scales = purge.getScales()
-        scalepaths = [prefix + '/@@images/image/' + str(i) for i in scales]
+        scalepaths = [prefix + "/@@images/image/" + str(i) for i in scales]
         [self.assertIn(j, paths) for j in scalepaths]
 
     def test_scale_purge_paths_unicode(self):
         purge = ScalesPurgePaths(self.file)
         expected = [
-            u'/plone/media/file/view/++widget++form.widgets.file/@@download/data/töstfile.csv',  # noqa: E501
-            u'/plone/media/file/@@download/file/data/töstfile.csv',
+            u"/plone/media/file/view/++widget++form.widgets.file/@@download/data/töstfile.csv",  # noqa: E501
+            u"/plone/media/file/@@download/file/data/töstfile.csv",
         ]
         if six.PY2:
             # the getRelativePaths method returns bytes on Python 2
-            expected = [x.encode('utf8') for x in expected]
+            expected = [x.encode("utf8") for x in expected]
         self.assertListEqual(
             list(purge.getRelativePaths()),
             expected,
